`pysoundanalyser`, a program for visualizing short sounds.
Webpage: https://samcarcagno.altervista.org/pysoundanalyser/pysoundanalyser.html

Copyright 2010-2023 Samuele Carcagno <sam.carcagno@gmail.com>



